##  Predefined Dashboards
You can activate predefined dashboards tailored to specific use cases by enabling respective checkboxes in the Predefined Dashboards settings group. Users can not edit or delete predefined dashboards.
